Summary:		Performance monitoring tools for Linux
Name:			sysstat
Version:		12.6.0
Release:		5%{?dist}
License:		GPLv2+
URL:			http://sebastien.godard.pagesperso-orange.fr/
Source0:		https://github.com/sysstat/sysstat/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:	gcc gettext make lm_sensors-devel systemd-rpm-macros
Requires:		xz findutils

%description
The sysstat package contains various utilities to monitor system performance 
and usage activity:
- iostat reports CPU statistics and input/output statistics for block devices 
  and partitions.
- mpstat reports individual or combined processor related statistics.
- pidstat reports statistics for Linux tasks (processes) : I/O, CPU, memory, etc.
- tapestat reports statistics for tape drives connected to the system.
- cifsiostat reports CIFS statistics.

Sysstat also contains tools you can schedule via cron or systemd to collect 
and historize performance and activity data:
- sar collects, reports and saves system activity information.
- sadc is the system activity data collector, used as a backend for sar.
- sa1 collects and stores binary data in the system activity daily data file. It 
  is a front end to sadc designed to be run from cron or systemd.
- sa2 writes a summarized daily activity report. It is a front end to sar designed
  to be run from cron or systemd.
- sadf displays data collected by sar in multiple formats (CSV, XML, JSON, etc.) 
  and can be used for data exchange with other programs. This command can also be
  used to draw graphs for the various activities collected by sar using SVG 
  (Scalable Vector Graphics) format.

%prep
%autosetup

%build
%configure \
    --enable-install-cron \
    --enable-copy-only \
    --disable-file-attr \
    --disable-stripping \
    --docdir='%{_pkgdocdir}' \
    --with-systemdsystemunitdir='%{_unitdir}' \
    --with-systemdsleepdir='%{_unitdir}-sleep' \
    sadc_options='-S DISK' \
    history=28 \
    compressafter=31
%make_build

%install
%make_install

rm -f %{buildroot}%{_defaultdocdir}/%{name}/COPYING

%find_lang %{name}

%post
%systemd_post sysstat.service sysstat-collect.timer sysstat-summary.timer

%preun
%systemd_preun sysstat.service sysstat-collect.timer sysstat-summary.timer
if [[ $1 -eq 0 ]]; then
    rm -rf %{_localstatedir}/log/sa/*
fi

%postun
%systemd_postun sysstat.service sysstat-collect.timer sysstat-summary.timer

%files -f %{name}.lang
%license COPYING
%doc CHANGES CREDITS FAQ.md README.md %{name}-%{version}.lsm
%config(noreplace) %{_sysconfdir}/sysconfig/sysstat
%config(noreplace) %{_sysconfdir}/sysconfig/sysstat.ioconf
%{_unitdir}/sysstat*
%{_systemd_util_dir}/system-sleep/sysstat*
%{_localstatedir}/log/sa
%{_bindir}/*
%{_libdir}/sa
%{_mandir}/man*/*

%changelog
* Wed Aug 7 2024 Chunsheng Luo <luffyluo@tencent.com> - 12.6.0-5
- Modify the Source to adapt to automatic upgrade

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 12.6.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 12.6.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 12.6.0-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Jun 30 2022 Xiaojie Chen <jackxjchen@tencent.com> - 12.6.0-1
- Initial build
